@@ -295,7 +295,7 @@ class axicdma:
             else:
                 time.sleep(0.001)
             if i == timeout-1:
-                print('CDMA time out!')
+                print('CDMA time out (pre)!')
                 return 1
         cr_value = self.axil.read32(CR_ADDR)
         new_cr_value = setbit(cr_value,12,0)
@@ -311,13 +311,13 @@ class axicdma:
                 else:
                     time.sleep(0.001)
                 if i == timeout-1:
-                    print('CDMA time out!')
+                    print('CDMA time out (post)!')
                     return 1
         sr_value = self.axil.read32(SR_ADDR)
         new_sr_value = setbit(sr_value,12,1)
         self.axil.write32(new_sr_value,SR_ADDR)
         return 0
-    def movedata(self,src_addr,dst_addr,size,timeout=2000,sync=False):
+    def movedata(self,src_addr,dst_addr,size,timeout=5000,sync=False):
         for loc in range(0,size,self.dma_bufsize):
             curr_loc_src = src_addr + loc
             curr_loc_dst = dst_addr + loc
